@@ -8,12 +8,14 @@ parentFolder = os.getcwd()
 print("Generate Quotes from Goodreads website.\n")
 author = input("Author to search:\n")
 book = input("Book name as per Goodreads:\n")
-
+saveFile = f"{author}.txt"
 
 # pickle = f"{parentFolder}\\{author}"
 # gr.Quotes.generateDB(author,saveFile=pickle)
-db = gr.Quotes.generateDB(author)
-# db = gr.Quotes.loadDB(pickle)
+if os.path.isfile(saveFile):
+    db = gr.Quotes.loadDB(saveFile)
+else:
+    db = gr.Quotes.generateDB(author, saveFile=f"{author}.txt")
 # titles = gr.Quotes.bookTitles(db)
 # print(titles)
 
@@ -21,7 +23,7 @@ db = gr.Quotes.generateDB(author)
 qts = gr.Quotes.filterQuotesByBook(db,book)
 # print(qts)
 
-gr.Quotes.export(qts,f"{parentFolder}\\{author}.txt",enc=1)
+gr.Quotes.export(qts,f"{parentFolder}\\{saveFile}",enc=1)
 
 # for quote in db:
 #     print(quote)
\ No newline at end of file
